import 'dart:collection';
import 'dart:convert';

import 'package:polyglothq/src/common/model/translation.dart';
import 'package:recase/recase.dart';

/// Maps the translations response to arb for Flutter app
class ArbMapper {
  final LinkedHashMap<String, dynamic> _map = LinkedHashMap<String, dynamic>();

  String map(List<Translation> translations, String locale) {
    _map['@@locale'] = locale;

    translations.sort((a, b) =>
        a.translationKey!.name.compareTo(b.translationKey!.name.toString()));
    for (final trans in translations) {
      var args = 0;
      Map<String, Map> placeholders = {};
      final tempValue = trans.value?.replaceAllMapped('%s', (match) {
        placeholders['arg$args'] = {};
        return '{arg${args++}}';
      });
      _map[trans.translationKey!.name.camelCase] = tempValue;
      _map['@${trans.translationKey!.name.camelCase}'] = {"type": "text"};
      if (placeholders.isNotEmpty) {
        _map['@${trans.translationKey!.name.camelCase}'] = {
          "type": "text",
          "placeholders": placeholders
        };
      }
    }

    var encoder = JsonEncoder.withIndent('     ');
    return encoder.convert(_map).replaceAll("\\\\", '\\');
  }
}
