import 'dart:async';
import 'dart:io';

import 'package:args/command_runner.dart';
import 'package:console/console.dart';
import 'package:polyglothq/src/common/model/user_request.dart';
import 'package:polyglothq/src/domain/repository/api_repository.dart';
import 'package:polyglothq/src/domain/repository/token_repository.dart';

class CommandLogin extends Command {
  CommandLogin(this._apiRepository, this._tokenRepository);

  final ApiRepository _apiRepository;
  final TokenRepository _tokenRepository;

  @override
  String get name => 'login';

  @override
  String get description =>
      'Fetches and writes your token to the keychain using the email and password you provide.';

  @override
  FutureOr<void> run() async {
    stdout.writeln('Logging into API...');
    Console.setTextColor(2);
    final email = await readInput('Email: ',
        checker: (value) => value.isNotEmpty && value.contains('@'));
    final password = await readInput('Password: ',
        secret: true, checker: (value) => value.isNotEmpty);
    Console.resetAll();

    try {
      final user = await _apiRepository.login(UserRequest(email, password));
      await _tokenRepository.saveToken(user.token);
      stdout.writeln('Logged In Successfully');
      exitCode = 0;
    } catch (e) {
      Console.setTextColor(1);
      stderr.writeln(
          'You are not authorized. Please call `polyglothq login` and provide correct credentials.');
      Console.resetAll();
      exit(2);
    }
  }
}
