import 'dart:async';
import 'dart:io';

import 'package:args/command_runner.dart';
import 'package:console/console.dart';
import 'package:polyglothq/src/domain/commands/command_login.dart';
import 'package:polyglothq/src/domain/repository/api_repository.dart';
import 'package:polyglothq/src/domain/repository/token_repository.dart';

class CommandProjects extends Command {
  CommandProjects(
      this._commandLogin, this._apiRepository, this._tokenRepository);

  final CommandLogin _commandLogin;
  final ApiRepository _apiRepository;
  final TokenRepository _tokenRepository;

  @override
  String get name => 'projects';

  @override
  String get description =>
      'Lists all available polyglot projects with their IDs.';

  @override
  FutureOr<void> run() async {
    while (!await _tokenRepository.loadToken()) {
      await _commandLogin.run();
    }

    stdout.writeln('Getting projects...');
    try {
      final projects = await _apiRepository.getProjects();
      projects.sort((a, b) => a.name.compareTo(b.name));

      stdout.writeln('  ID  => Name:');
      stdout.writeln('  ------------');
      stdout.writeln('');
      for (final project in projects) {
        stdout.writeln(
            '  ${project.id.toString().padRight(3)} => ${project.name}');
      }
      exit(0);
    } catch (e) {
      TextPen().red().text('Error fetching projects').print();
      exit(2);
    }
  }
}
