import 'dart:io';

import 'package:args/args.dart';
import 'package:args/command_runner.dart';
import 'package:get_it/get_it.dart';
import 'package:polyglothq/src/domain/commands/command_init.dart';
import 'package:polyglothq/src/domain/commands/command_login.dart';
import 'package:polyglothq/src/domain/commands/command_projects.dart';
import 'package:polyglothq/src/domain/commands/command_pull.dart';
import 'package:polyglothq/src/version.dart';

class PolyglotCommandRunner extends CommandRunner {
  PolyglotCommandRunner()
      : super('polyglothq',
            'A Flutter CLI for managing polyglot\'s translations.') {
    argParser.addFlag('version',
        abbr: 'v', negatable: false, help: 'Display version information');
    argParser.addFlag('trace',
        abbr: 't',
        negatable: false,
        help: 'Display backtrace when an error occurs');
    addCommand(GetIt.I.get<CommandLogin>());
    addCommand(GetIt.I.get<CommandInit>());
    addCommand(GetIt.I.get<CommandProjects>());
    addCommand(GetIt.I.get<CommandPull>());
  }

  @override
  Future<void> runCommand(ArgResults topLevelResults) async {
    if (topLevelResults['version'] == true) {
      stdout.writeln(packageVersion);
    } else {
      await super.runCommand(topLevelResults);
    }
  }
}
