import 'package:dio/dio.dart';
import 'package:polyglothq/src/common/model/language.dart';
import 'package:polyglothq/src/common/model/project.dart';
import 'package:polyglothq/src/common/model/translation.dart';
import 'package:polyglothq/src/common/model/user_request.dart';
import 'package:polyglothq/src/common/model/user_response.dart';
import 'package:polyglothq/src/domain/repository/api_repository.dart';
import 'package:polyglothq/src/source_remote/dio/api_endpoints.dart';

class ApiRepositoryImpl implements ApiRepository {
  ApiRepositoryImpl(this._dio);

  final Dio _dio;

  @override
  Future<UserResponse> login(UserRequest userRequest) async {
    final response =
        await _dio.post(ApiEndpoints.login, data: userRequest.toJson());
    return UserResponse.fromJson(response.data);
  }

  @override
  Future<List<Language>> getLanguages(String projectId) async {
    final response = await _dio.get(
      ApiEndpoints.languages,
      queryParameters: {'filter[project_id]': projectId},
    );
    final x = response.data['data']
        .map<Language>((element) => Language.fromJson(element!))
        .toList();
    return x;
  }

  @override
  Future<List<Translation>> getTranslations(
      String projectId, String languageId) async {
    List<Translation> translationsList = [];
    var currentPage = 1;
    late Response response;
    do {
      response = await _dio.get(
        ApiEndpoints.translations,
        queryParameters: {
          'filter[project_id]': projectId,
          'filter[language_id]': languageId,
          'page[size]': '100',
          'page[number]': currentPage,
        },
      );
      final translationsData = response.data['data']
          .map<Translation>((element) => Translation.fromJson(element!))
          .toList();
      translationsList.addAll(translationsData);
      currentPage++;
    } while (response.data['links']['self'] != response.data['links']['last']);

    return translationsList;
  }

  @override
  Future<List<Project>> getProjects() async {
    List<Project> projectsList = [];
    var currentPage = 1;
    late Response response;
    do {
      response = await _dio.get(
        ApiEndpoints.projects,
        queryParameters: {
          'page[size]': '100',
          'page[number]': currentPage,
        },
      );
      final projectsBody = response.data['data']
          .map<Project>((element) => Project.fromJson(element!))
          .toList();
      projectsList.addAll(projectsBody);
      currentPage++;
    } while (response.data['links']['self'] != response.data['links']['last']);

    return projectsList;
  }
}
